"use strict";

/**
 * get class by obj
 * @param obj
 */
const getClass = obj => Object.prototype.toString.call(obj).slice(8, -1);

/**
 * validate `type` is `obj type`
 * @param type
 * @param obj
 * @returns {boolean}
 */
const is = (type, obj) => {
  const clazz = getClass(obj);
  return obj !== undefined && obj !== null && clazz === type;
};

/**
 * calculate check digit by code128 code-c
 * @param value
 * @returns {number}
 */
const calculateCheckDigit = value => {
  let total = 0;
  let totalOdd = 0;
  let totalEven = 0;
  const length = value.length;
  Array.prototype.forEach.call(value, function(currentValue, index, value) {
    if (isEven(index)) {
      totalEven += parseInt(currentValue);
    } else {
      totalOdd += parseInt(currentValue);
    }
  });
  if (isEven(length)) {
    total = totalEven + totalOdd * 3;
  } else {
    total = totalEven * 3 + totalOdd;
  }
  return (10 - total % 10) % 10;
};

/**
 * is even value
 * @param value
 * @returns {boolean}
 */
const isEven = value => {
  return value % 2 === 0;
};

module.exports = {
  is,
  calculateCheckDigit
};
